@@ -93,9 +93,9 @@ from mercurial import (
 
 from mercurial.i18n import _
 
-__version__ = b'0.1.1'
-testedwith = b'4.4 4.5 4.6 4.7.1'
-minimumhgversion = b'4.4'
+__version__ = b'0.1.2'
+testedwith = b'4.6.2 4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5'
+minimumhgversion = b'4.6'
 buglink = b'https://bz.mercurial-scm.org/'
 
 cmdtable = {}
@@ -190,7 +190,12 @@ def sliceoutgoing(repo, outgoing):
         ms = missingrevs.copy()
         ss = []
     allslices = []
-    missingheads = [rev(n) for n in sorted(outgoing.missingheads, reverse=True)]
+    # hg <= 5.4 (c93dd9d9f1e6)
+    if util.safehasattr(outgoing, 'ancestorsof'):
+        missingheads = outgoing.ancestorsof
+    else:
+        missingheads = outgoing.missingheads
+    missingheads = [rev(n) for n in sorted(missingheads, reverse=True)]
     for head in missingheads:
         localslices = []
         localmissing = set(repo.revs(b'%ld and ::%d', missingrevs, head))
@@ -375,9 +380,11 @@ def poweroftwo(num):
     return num and not num & (num - 1)
 
 def outgoingfromnodes(repo, nodes):
-    return discovery.outgoing(repo,
-                              missingroots=nodes,
-                              missingheads=nodes)
+    # hg <= 5.4 (c93dd9d9f1e6)
+    if r'ancestorsof' in discovery.outgoing.__init__.__code__.co_varnames:
+        return discovery.outgoing(repo, missingroots=nodes, ancestorsof=nodes)
+    else:
+        return discovery.outgoing(repo, missingroots=nodes, missingheads=nodes)
 
 # changegroup part construction
 
